@@ -99,9 +99,9 @@ class JManCon:
             req = requests.post(url=self._config.url() + url, headers=headers, data=data)
         except requests.exceptions.RequestException:
             raise JManErrorConnection()
-        if req.status_code < 200:
+        if req.status_code < 200 or 300 <= req.status_code < 400:
             raise JManErrorConnection()
-        if req.status_code < 200 or 200 < req.status_code <= 300 or req.status_code >= 500:
+        if req.status_code < 200 or req.status_code >= 500:
             raise JManErrorApp()
         if 400 <= req.status_code < 500:
             raise JManErrorClient()
@@ -120,9 +120,9 @@ class JManCon:
             req = requests.put(url=self._config.url() + url, headers=headers, data=data)
         except requests.exceptions.RequestException:
             raise JManErrorConnection()
-        if req.status_code < 200:
+        if req.status_code < 200 or 300 <= req.status_code < 400:
             raise JManErrorConnection()
-        if req.status_code < 200 or 200 < req.status_code <= 300 or req.status_code >= 500:
+        if req.status_code < 200 or req.status_code >= 500:
             raise JManErrorApp()
         if 400 <= req.status_code < 500:
             raise JManErrorClient()
@@ -137,9 +137,9 @@ class JManCon:
             req = requests.get(url=self._config.url() + url, headers=headers)
         except requests.exceptions.RequestException:
             raise JManErrorConnection()
-        if req.status_code < 200:
+        if req.status_code < 200 or 300 <= req.status_code < 400:
             raise JManErrorConnection()
-        if req.status_code < 200 or 200 < req.status_code <= 300 or req.status_code >= 500:
+        if req.status_code < 200 or req.status_code >= 500:
             raise JManErrorApp()
         if 400 <= req.status_code < 500:
             raise JManErrorClient()
@@ -151,13 +151,13 @@ class JManCon:
             req = requests.delete(url=self._config.url() + url, headers=headers)
         except requests.exceptions.RequestException:
             raise JManErrorConnection()
-        if req.status_code < 200:
+        if req.status_code < 200 or 300 <= req.status_code < 400:
             raise JManErrorConnection()
-        if req.status_code < 200 or 200 < req.status_code <= 300 or req.status_code >= 500:
+        if req.status_code < 200 or req.status_code >= 500:
             raise JManErrorApp()
         if 400 <= req.status_code < 500:
             raise JManErrorClient()
         return req
 
     def __del__(self):
-        self.delete(url='/logout')
\ No newline at end of file
+        self.delete(url='/logout')
